 # COVID-19 Patient Assessment Implementation Guide

This Questionnaire captures the questions used in the CovApp, which can help citizens to better assess their medical condition, provides recommendations regarding doctor’s visits or coronavirus testing, and summarizes relevant medical information for future doctor’s consultation. The app is available at https://covapp.data4life.care. The source code is freely available at https://github.com/d4l-data4life/covapp. FAQ can be found at https://www.d4l.io/blog/covapp-faq/.

The associated FHIR artifacts were developed by [Data4Life](http://data4life.care) in cooperation with

* [Charité – Universitätsmedizin Berlin](https://www.charite.de/en/),
* The core unit ["eHealth and Interoperability"](https://www.bihealth.org/en/research/core-facilities/interoperability/) at the [Berlin Institute of Health](https://www.bihealth.org/)
* [hih – health innovation hub](https://hih-2025.de/en/) of the German Federal Ministry of Health
* The [MOLIT Institute](https://molit.eu/en/landing-page/).

Contributing authors:

* Morten Ernebjerg, PhD (Data4Life)
* Peter Osburg (Data4Life)
* Julian Sass (Berlin Institute of Health)
* Patrick Werner (MOLIT Institute)
* Dr. med. Kai Heitmann (Health Innovation Hub)
* Dr. Valerie Kirchberger (Charité)
* Prof. Dr. Sylvia Thun (Berlin Institute of Health)

## How to use this implementation guide
This implementation guide describes how to use FHIR to capture the questions asked by the CovApp and the corresponding output (set of answers). Despite being  based on the CovApp, it is a general specification that is not tied to a specific software implementation and can be used in other scenarios. 

The core FHIR artifact is the Questionnaire resource, which defines the COVID-19-related questions. This resource also defines the structure of a valid set of answers. Such answers can be captured with a QuestionResponse FHIR resource, for which we provide an example. The CovApp can also generate [QuestionnaireResponse FHIR output directly](https://github.com/d4l-data4life/covapp#questionnaire-answers-in-fhir-format).

To clearly label and classify the collected information, we use codes coming from standard or custom systems of codes (CodeSystem resources). The relevant codes are bundled in value sets (ValueSet resources) containing sets of codes used for a specific purpose, for example, allowed answers to a multiple-choice question. When answer sets are captured as QuestionnaireResponse resources, the answers to multiple-choice questions are stored as codes from the corresponding value set. The link between questions and answer value set is given in the Questionnaire resource. This connection between answers and value set codes ensures interoperability as it provides a translation-independent interpretation of the answers. 

All resources are provided in two versions, one with texts in English and one with texts in German. The only exception are CodeSystem resources, which include labels for both languages.

## Disclaimer

Though great care has been taken in the preparation of this implementation guide, this implementation guide is provided "as is“ without warranty of any kind and D4L data4life gGmbH, as well as cooperation partners, shall in no event be liable for any claims, direct or indirect damages and the like arising from, out of or in connection with the implementation guide or its use.

## License and copyright notices

The material in this specification is public. Users are free to copy, modify, and redistribute this material without any restrictions.

The above copyright notice, the disclaimer and this permission notice shall be included in all copies or substantial portions of this implementation guide.

This implementation guide copyright © 2020 D4L data4life gGmbH, Berlin Institute of Health, MOLIT Institute, Health Innovation Hub, Charité - Universtätsmedizin Berlin.

### FHIR

The HL7® FHIR® standard is Copyright © 2011+ HL7 and is used under the [FHIR license terms](http://hl7.org/fhir/license.html)

### LOINC

>This product includes all, or a portion of, or is derived from content from LOINC that is subject to a license from Regenstrief Institute, Inc. Your use of the LOINC content also is subject to this license, a copy of which is available at https://loinc.org/license/. The current complete distribution is available for download at http://loinc.org. The LOINC Table and LOINC codes are copyright © 1995-2019, Regenstrief Institute, Inc. and the Logical Observation Identifiers Names and Codes (LOINC) Committee. The LOINC Table, LOINC Table Core, LOINC Panels and Forms File, LOINC Answer File, LOINC Part File, LOINC Group File, LOINC Document Ontology File, LOINC Document Ontology OWL File, LOINC Hierarchies, LOINC Linguistic Variants File, LOINC/RSNA Radiology Playbook, LOINC/IEEE Medical Device Code Mapping Table, and LOINC Consumer Name File, and LOINC Change Snapshot File are copyright © 1995-2019, Regenstrief Institute, Inc. All rights reserved. THE LOINC TABLE (IN ALL FORMATS), LOINC TABLE CORE, LOINC PANELS AND FORMS FILE, LOINC ANSWER FILE, LOINC PART FILE, LOINC GROUP FILE, LOINC DOCUMENT ONTOLOGY FILE, LOINC DOCUMENT ONTOLOGY OWL FILE, LOINC HIERARCHIES, LOINC LINGUISTIC VARIANTS FILE, LOINC/RSNA RADIOLOGY PLAYBOOK, LOINC/IEEE MEDICAL DEVICE CODE MAPPING TABLE, LOINC CONSUMER NAME FILE, AND LOINC CHANGE SNAPSHOT FILE ARE PROVIDED "AS IS." ANY EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. LOINC® is a registered United States trademark of Regenstrief Institute, Inc. A small portion of LOINC content may include content (e.g., survey instruments) that is subject to copyrights owned by third parties. Such content has been mapped to LOINC terms under applicable copyright and terms of use. Notice of such third-party copyright and license terms would need to be included if such content is included.

### SNOMED

All SNOMED CT codes in this project come from the [SNOMED Global Patient Set (GPS)](http://www.snomed.org/snomed-international/learn-more/global-patient-set) which is available under the following license terms:

>The GPS is produced by SNOMED International under the terms of the [Creative Commons Attribution 4.0 International Public License](https://creativecommons.org/licenses/by/4.0/)
>
>Additional information about this license specific to SNOMED International’s release of the GPS:
>
>* SNOMED CT is © and ® SNOMED International. The right to maintain the GPS remains vested exclusively in SNOMED International.
>* The Licensee can redistribute the GPS.
>* The Licensee can create derivatives or implementation-related products and services based on the GPS.
>* The Licensee cannot claim that SNOMED International or any of its Members endorses the Licensee’s derivative because it uses content from the GPS.
>* Neither SNOMED International nor any of the contributors accept any liability for the Licensee’s use or redistribution of the GPS.
>* SNOMED CT® was originally created by the College of American Pathologists.
>
>Without obtaining prior written permission from SNOMED International, you are expressly prohibited from using, distributing or reproducing the SNOMED International, SNOMED CT or SNOMED GPS logo, service mark or trademark. Please review all terms and conditions of use [here](http://www.snomed.org/terms-and-conditions).
